/// <reference types="node" />
import * as gax from 'google-gax';
import { Callback, Descriptors, ClientOptions, PaginationCallback } from 'google-gax';
import { Transform } from 'stream';
import * as protos from '../../protos/protos';
/**
 *  Manages external data source connections and credentials.
 * @class
 * @memberof v1
 */
export declare class ConnectionServiceClient {
    private _terminated;
    private _opts;
    private _gaxModule;
    private _gaxGrpc;
    private _protos;
    private _defaults;
    auth: gax.GoogleAuth;
    descriptors: Descriptors;
    innerApiCalls: {
        [name: string]: Function;
    };
    pathTemplates: {
        [name: string]: gax.PathTemplate;
    };
    connectionServiceStub?: Promise<{
        [name: string]: Function;
    }>;
    /**
     * Construct an instance of ConnectionServiceClient.
     *
     * @param {object} [options] - The configuration object. See the subsequent
     *   parameters for more details.
     * @param {object} [options.credentials] - Credentials object.
     * @param {string} [options.credentials.client_email]
     * @param {string} [options.credentials.private_key]
     * @param {string} [options.email] - Account email address. Required when
     *     using a .pem or .p12 keyFilename.
     * @param {string} [options.keyFilename] - Full path to the a .json, .pem, or
     *     .p12 key downloaded from the Google Developers Console. If you provide
     *     a path to a JSON file, the projectId option below is not necessary.
     *     NOTE: .pem and .p12 require you to specify options.email as well.
     * @param {number} [options.port] - The port on which to connect to
     *     the remote host.
     * @param {string} [options.projectId] - The project ID from the Google
     *     Developer's Console, e.g. 'grape-spaceship-123'. We will also check
     *     the environment variable GCLOUD_PROJECT for your project ID. If your
     *     app is running in an environment which supports
     *     {@link https://developers.google.com/identity/protocols/application-default-credentials Application Default Credentials},
     *     your project ID will be detected automatically.
     * @param {string} [options.apiEndpoint] - The domain name of the
     *     API remote host.
     */
    constructor(opts?: ClientOptions);
    /**
     * Initialize the client.
     * Performs asynchronous operations (such as authentication) and prepares the client.
     * This function will be called automatically when any class method is called for the
     * first time, but if you need to initialize it before calling an actual method,
     * feel free to call initialize() directly.
     *
     * You can await on this method if you want to make sure the client is initialized.
     *
     * @returns {Promise} A promise that resolves to an authenticated service stub.
     */
    initialize(): Promise<{
        [name: string]: Function;
    }>;
    /**
     * The DNS address for this API service.
     */
    static get servicePath(): string;
    /**
     * The DNS address for this API service - same as servicePath(),
     * exists for compatibility reasons.
     */
    static get apiEndpoint(): string;
    /**
     * The port for this API service.
     */
    static get port(): number;
    /**
     * The scopes needed to make gRPC calls for every method defined
     * in this service.
     */
    static get scopes(): string[];
    getProjectId(): Promise<string>;
    getProjectId(callback: Callback<string, undefined, undefined>): void;
    createConnection(request: protos.google.cloud.bigquery.connection.v1.ICreateConnectionRequest, options?: gax.CallOptions): Promise<[protos.google.cloud.bigquery.connection.v1.IConnection, (protos.google.cloud.bigquery.connection.v1.ICreateConnectionRequest | undefined), {} | undefined]>;
    createConnection(request: protos.google.cloud.bigquery.connection.v1.ICreateConnectionRequest, options: gax.CallOptions, callback: Callback<protos.google.cloud.bigquery.connection.v1.IConnection, protos.google.cloud.bigquery.connection.v1.ICreateConnectionRequest | null | undefined, {} | null | undefined>): void;
    createConnection(request: protos.google.cloud.bigquery.connection.v1.ICreateConnectionRequest, callback: Callback<protos.google.cloud.bigquery.connection.v1.IConnection, protos.google.cloud.bigquery.connection.v1.ICreateConnectionRequest | null | undefined, {} | null | undefined>): void;
    getConnection(request: protos.google.cloud.bigquery.connection.v1.IGetConnectionRequest, options?: gax.CallOptions): Promise<[protos.google.cloud.bigquery.connection.v1.IConnection, (protos.google.cloud.bigquery.connection.v1.IGetConnectionRequest | undefined), {} | undefined]>;
    getConnection(request: protos.google.cloud.bigquery.connection.v1.IGetConnectionRequest, options: gax.CallOptions, callback: Callback<protos.google.cloud.bigquery.connection.v1.IConnection, protos.google.cloud.bigquery.connection.v1.IGetConnectionRequest | null | undefined, {} | null | undefined>): void;
    getConnection(request: protos.google.cloud.bigquery.connection.v1.IGetConnectionRequest, callback: Callback<protos.google.cloud.bigquery.connection.v1.IConnection, protos.google.cloud.bigquery.connection.v1.IGetConnectionRequest | null | undefined, {} | null | undefined>): void;
    updateConnection(request: protos.google.cloud.bigquery.connection.v1.IUpdateConnectionRequest, options?: gax.CallOptions): Promise<[protos.google.cloud.bigquery.connection.v1.IConnection, (protos.google.cloud.bigquery.connection.v1.IUpdateConnectionRequest | undefined), {} | undefined]>;
    updateConnection(request: protos.google.cloud.bigquery.connection.v1.IUpdateConnectionRequest, options: gax.CallOptions, callback: Callback<protos.google.cloud.bigquery.connection.v1.IConnection, protos.google.cloud.bigquery.connection.v1.IUpdateConnectionRequest | null | undefined, {} | null | undefined>): void;
    updateConnection(request: protos.google.cloud.bigquery.connection.v1.IUpdateConnectionRequest, callback: Callback<protos.google.cloud.bigquery.connection.v1.IConnection, protos.google.cloud.bigquery.connection.v1.IUpdateConnectionRequest | null | undefined, {} | null | undefined>): void;
    deleteConnection(request: protos.google.cloud.bigquery.connection.v1.IDeleteConnectionRequest, options?: gax.CallOptions): Promise<[protos.google.protobuf.IEmpty, (protos.google.cloud.bigquery.connection.v1.IDeleteConnectionRequest | undefined), {} | undefined]>;
    deleteConnection(request: protos.google.cloud.bigquery.connection.v1.IDeleteConnectionRequest, options: gax.CallOptions, callback: Callback<protos.google.protobuf.IEmpty, protos.google.cloud.bigquery.connection.v1.IDeleteConnectionRequest | null | undefined, {} | null | undefined>): void;
    deleteConnection(request: protos.google.cloud.bigquery.connection.v1.IDeleteConnectionRequest, callback: Callback<protos.google.protobuf.IEmpty, protos.google.cloud.bigquery.connection.v1.IDeleteConnectionRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.iam.v1.IGetIamPolicyRequest, options?: gax.CallOptions): Promise<[protos.google.iam.v1.IPolicy, protos.google.iam.v1.IGetIamPolicyRequest | undefined, {} | undefined]>;
    getIamPolicy(request: protos.google.iam.v1.IGetIamPolicyRequest, options: gax.CallOptions, callback: Callback<protos.google.iam.v1.IPolicy, protos.google.iam.v1.IGetIamPolicyRequest | null | undefined, {} | null | undefined>): void;
    getIamPolicy(request: protos.google.iam.v1.IGetIamPolicyRequest, callback: Callback<protos.google.iam.v1.IPolicy, protos.google.iam.v1.IGetIamPolicyRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.iam.v1.ISetIamPolicyRequest, options?: gax.CallOptions): Promise<[protos.google.iam.v1.IPolicy, protos.google.iam.v1.ISetIamPolicyRequest | undefined, {} | undefined]>;
    setIamPolicy(request: protos.google.iam.v1.ISetIamPolicyRequest, options: gax.CallOptions, callback: Callback<protos.google.iam.v1.IPolicy, protos.google.iam.v1.ISetIamPolicyRequest | null | undefined, {} | null | undefined>): void;
    setIamPolicy(request: protos.google.iam.v1.ISetIamPolicyRequest, callback: Callback<protos.google.iam.v1.IPolicy, protos.google.iam.v1.ISetIamPolicyRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.iam.v1.ITestIamPermissionsRequest, options?: gax.CallOptions): Promise<[protos.google.iam.v1.ITestIamPermissionsResponse, protos.google.iam.v1.ITestIamPermissionsRequest | undefined, {} | undefined]>;
    testIamPermissions(request: protos.google.iam.v1.ITestIamPermissionsRequest, options: gax.CallOptions, callback: Callback<protos.google.iam.v1.ITestIamPermissionsResponse, protos.google.iam.v1.ITestIamPermissionsRequest | null | undefined, {} | null | undefined>): void;
    testIamPermissions(request: protos.google.iam.v1.ITestIamPermissionsRequest, callback: Callback<protos.google.iam.v1.ITestIamPermissionsResponse, protos.google.iam.v1.ITestIamPermissionsRequest | null | undefined, {} | null | undefined>): void;
    listConnections(request: protos.google.cloud.bigquery.connection.v1.IListConnectionsRequest, options?: gax.CallOptions): Promise<[protos.google.cloud.bigquery.connection.v1.IConnection[], protos.google.cloud.bigquery.connection.v1.IListConnectionsRequest | null, protos.google.cloud.bigquery.connection.v1.IListConnectionsResponse]>;
    listConnections(request: protos.google.cloud.bigquery.connection.v1.IListConnectionsRequest, options: gax.CallOptions, callback: PaginationCallback<protos.google.cloud.bigquery.connection.v1.IListConnectionsRequest, protos.google.cloud.bigquery.connection.v1.IListConnectionsResponse | null | undefined, protos.google.cloud.bigquery.connection.v1.IConnection>): void;
    listConnections(request: protos.google.cloud.bigquery.connection.v1.IListConnectionsRequest, callback: PaginationCallback<protos.google.cloud.bigquery.connection.v1.IListConnectionsRequest, protos.google.cloud.bigquery.connection.v1.IListConnectionsResponse | null | undefined, protos.google.cloud.bigquery.connection.v1.IConnection>): void;
    /**
     * Equivalent to {@link listConnections}, but returns a NodeJS Stream object.
     *
     * This fetches the paged responses for {@link listConnections} continuously
     * and invokes the callback registered for 'data' event for each element in the
     * responses.
     *
     * The returned object has 'end' method when no more elements are required.
     *
     * autoPaginate option will be ignored.
     *
     * @see {@link https://nodejs.org/api/stream.html}
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.parent
     *   Required. Parent resource name.
     *   Must be in the form: `projects/{project_id}/locations/{location_id}`
     * @param {number} request.pageSize
     *   Required. Page size.
     * @param {string} request.pageToken
     *   Page token.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Stream}
     *   An object stream which emits an object representing [Connection]{@link google.cloud.bigquery.connection.v1.Connection} on 'data' event.
     */
    listConnectionsStream(request?: protos.google.cloud.bigquery.connection.v1.IListConnectionsRequest, options?: gax.CallOptions): Transform;
    /**
     * Equivalent to {@link listConnections}, but returns an iterable object.
     *
     * for-await-of syntax is used with the iterable to recursively get response element on-demand.
     *
     * @param {Object} request
     *   The request object that will be sent.
     * @param {string} request.parent
     *   Required. Parent resource name.
     *   Must be in the form: `projects/{project_id}/locations/{location_id}`
     * @param {number} request.pageSize
     *   Required. Page size.
     * @param {string} request.pageToken
     *   Page token.
     * @param {object} [options]
     *   Call options. See {@link https://googleapis.dev/nodejs/google-gax/latest/interfaces/CallOptions.html|CallOptions} for more details.
     * @returns {Object}
     *   An iterable Object that conforms to @link https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Iteration_protocols.
     */
    listConnectionsAsync(request?: protos.google.cloud.bigquery.connection.v1.IListConnectionsRequest, options?: gax.CallOptions): AsyncIterable<protos.google.cloud.bigquery.connection.v1.IConnection>;
    /**
     * Return a fully-qualified connection resource name string.
     *
     * @param {string} project
     * @param {string} location
     * @param {string} connection
     * @returns {string} Resource name string.
     */
    connectionPath(project: string, location: string, connection: string): string;
    /**
     * Parse the project from Connection resource.
     *
     * @param {string} connectionName
     *   A fully-qualified path representing Connection resource.
     * @returns {string} A string representing the project.
     */
    matchProjectFromConnectionName(connectionName: string): string | number;
    /**
     * Parse the location from Connection resource.
     *
     * @param {string} connectionName
     *   A fully-qualified path representing Connection resource.
     * @returns {string} A string representing the location.
     */
    matchLocationFromConnectionName(connectionName: string): string | number;
    /**
     * Parse the connection from Connection resource.
     *
     * @param {string} connectionName
     *   A fully-qualified path representing Connection resource.
     * @returns {string} A string representing the connection.
     */
    matchConnectionFromConnectionName(connectionName: string): string | number;
    /**
     * Return a fully-qualified location resource name string.
     *
     * @param {string} project
     * @param {string} location
     * @returns {string} Resource name string.
     */
    locationPath(project: string, location: string): string;
    /**
     * Parse the project from Location resource.
     *
     * @param {string} locationName
     *   A fully-qualified path representing Location resource.
     * @returns {string} A string representing the project.
     */
    matchProjectFromLocationName(locationName: string): string | number;
    /**
     * Parse the location from Location resource.
     *
     * @param {string} locationName
     *   A fully-qualified path representing Location resource.
     * @returns {string} A string representing the location.
     */
    matchLocationFromLocationName(locationName: string): string | number;
    /**
     * Terminate the GRPC channel and close the client.
     *
     * The client will no longer be usable and all future behavior is undefined.
     */
    close(): Promise<void>;
}
